/****************************************************************************
** Meta object code from reading C++ file 'blinkengame.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../blinken-26.07.90/src/blinkengame.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'blinkengame.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11BlinkenGameE_t {};
} // unnamed namespace

template <> constexpr inline auto BlinkenGame::qt_create_metaobjectdata<qt_meta_tag_ZN11BlinkenGameE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BlinkenGame",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "gameEnded",
        "",
        "phaseChanged",
        "highlight",
        "BlinkenGame::Color",
        "c",
        "unhighlight",
        "nextSound",
        "soundEnded",
        "waiting",
        "level",
        "canType",
        "phase",
        "GamePhase",
        "score",
        "clicked",
        "Color",
        "setPhase",
        "p",
        "start",
        "Starting",
        "ChoosingLevel",
        "Waiting3",
        "Waiting2",
        "Waiting1",
        "LearningTheSequence",
        "TypingTheSequence",
        "None",
        "Red",
        "Green",
        "Blue",
        "Yellow",
        "All"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'gameEnded'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'phaseChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'highlight'
        QtMocHelpers::SignalData<void(BlinkenGame::Color, bool)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::Bool, 11 },
        }}),
        // Slot 'nextSound'
        QtMocHelpers::SlotData<void()>(12, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'soundEnded'
        QtMocHelpers::SlotData<void()>(13, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'unhighlight'
        QtMocHelpers::SlotData<void()>(11, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'waiting'
        QtMocHelpers::SlotData<void()>(14, 6, QMC::AccessPrivate, QMetaType::Void),
        // Method 'level'
        QtMocHelpers::MethodData<int() const>(15, 6, QMC::AccessPublic, QMetaType::Int),
        // Method 'canType'
        QtMocHelpers::MethodData<bool() const>(16, 6, QMC::AccessPublic, QMetaType::Bool),
        // Method 'phase'
        QtMocHelpers::MethodData<enum GamePhase() const>(17, 6, QMC::AccessPublic, 0x80000000 | 18),
        // Method 'score'
        QtMocHelpers::MethodData<int() const>(19, 6, QMC::AccessPublic, QMetaType::Int),
        // Method 'clicked'
        QtMocHelpers::MethodData<void(enum Color)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 10 },
        }}),
        // Method 'setPhase'
        QtMocHelpers::MethodData<void(enum GamePhase)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 23 },
        }}),
        // Method 'start'
        QtMocHelpers::MethodData<void(int)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'phase'
        QtMocHelpers::PropertyData<enum GamePhase>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'GamePhase'
        QtMocHelpers::EnumData<enum GamePhase>(18, 18, QMC::EnumFlags{}).add({
            {   25, GamePhase::Starting },
            {   26, GamePhase::ChoosingLevel },
            {   27, GamePhase::Waiting3 },
            {   28, GamePhase::Waiting2 },
            {   29, GamePhase::Waiting1 },
            {   30, GamePhase::LearningTheSequence },
            {   31, GamePhase::TypingTheSequence },
        }),
        // enum 'Color'
        QtMocHelpers::EnumData<enum Color>(21, 21, QMC::EnumFlags{}).add({
            {   32, Color::None },
            {   33, Color::Red },
            {   34, Color::Green },
            {   35, Color::Blue },
            {   36, Color::Yellow },
            {   37, Color::All },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<BlinkenGame, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject BlinkenGame::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11BlinkenGameE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11BlinkenGameE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11BlinkenGameE_t>.metaTypes,
    nullptr
} };

void BlinkenGame::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BlinkenGame *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->gameEnded(); break;
        case 1: _t->phaseChanged(); break;
        case 2: _t->highlight((*reinterpret_cast<std::add_pointer_t<BlinkenGame::Color>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 3: _t->nextSound(); break;
        case 4: _t->soundEnded(); break;
        case 5: _t->unhighlight(); break;
        case 6: _t->waiting(); break;
        case 7: { int _r = _t->level();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->canType();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { enum GamePhase _r = _t->phase();
            if (_a[0]) *reinterpret_cast<enum GamePhase*>(_a[0]) = std::move(_r); }  break;
        case 10: { int _r = _t->score();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->clicked((*reinterpret_cast<std::add_pointer_t<enum Color>>(_a[1]))); break;
        case 12: _t->setPhase((*reinterpret_cast<std::add_pointer_t<enum GamePhase>>(_a[1]))); break;
        case 13: _t->start((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BlinkenGame::*)()>(_a, &BlinkenGame::gameEnded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BlinkenGame::*)()>(_a, &BlinkenGame::phaseChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BlinkenGame::*)(BlinkenGame::Color , bool )>(_a, &BlinkenGame::highlight, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum GamePhase*>(_v) = _t->phase(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPhase(*reinterpret_cast<enum GamePhase*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *BlinkenGame::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BlinkenGame::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11BlinkenGameE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BlinkenGame::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void BlinkenGame::gameEnded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void BlinkenGame::phaseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void BlinkenGame::highlight(BlinkenGame::Color _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}
QT_WARNING_POP
